"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MosaicSearchOptions = void 0;
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
const clime_1 = require("clime");
const search_command_1 = require("../../interfaces/search.command");
const search_options_1 = require("../../interfaces/search.options");
const address_resolver_1 = require("../../resolvers/address.resolver");
const formatter_service_1 = require("../../services/formatter.service");
const info_1 = require("./info");
/**
 * Search options
 */
class MosaicSearchOptions extends search_options_1.SearchOptions {
    async buildSearchCriteria() {
        const criteria = await this.buildBaseSearchCriteria();
        if (this.ownerAddress) {
            criteria.ownerAddress = await new address_resolver_1.AddressResolver().resolve(this, undefined, undefined, 'ownerAddress');
        }
        return criteria;
    }
}
__decorate([
    clime_1.option({
        description: '(Optional) Filter by owner address.',
    }),
    __metadata("design:type", String)
], MosaicSearchOptions.prototype, "ownerAddress", void 0);
exports.MosaicSearchOptions = MosaicSearchOptions;
let default_1 = class default_1 extends search_command_1.SearchCommand {
    constructor() {
        super();
    }
    async execute(options) {
        const profile = this.getProfile(options);
        this.spinner.start();
        const mosaicHttp = profile.repositoryFactory.createMosaicRepository();
        mosaicHttp.search(await options.buildSearchCriteria()).subscribe((page) => {
            this.spinner.stop();
            if (!page.data.length) {
                console.log(formatter_service_1.FormatterService.error('No data found; try changing the selection criteria'));
            }
            page.data.forEach((mosaic) => {
                console.log(new info_1.MosaicViewTable(mosaic).toString());
            });
        }, (err) => {
            this.spinner.stop();
            console.log(formatter_service_1.FormatterService.error(err));
        });
    }
};
__decorate([
    clime_1.metadata,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [MosaicSearchOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    clime_1.command({
        description: 'Search mosaics',
    }),
    __metadata("design:paramtypes", [])
], default_1);
exports.default = default_1;
