"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NamespaceInfoTable = exports.CommandOptions = void 0;
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
const Table = require("cli-table3");
const clime_1 = require("clime");
const profile_command_1 = require("../../interfaces/profile.command");
const profile_options_1 = require("../../interfaces/profile.options");
const namespace_resolver_1 = require("../../resolvers/namespace.resolver");
const formatter_service_1 = require("../../services/formatter.service");
class CommandOptions extends profile_options_1.ProfileOptions {
}
__decorate([
    clime_1.option({
        flag: 'n',
        description: 'Namespace name. Example: symbol.xym',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "namespaceName", void 0);
__decorate([
    clime_1.option({
        flag: 'h',
        description: 'Namespace id in hexadecimal.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "namespaceId", void 0);
exports.CommandOptions = CommandOptions;
class NamespaceInfoTable {
    constructor(namespaceInfo) {
        this.namespaceInfo = namespaceInfo;
        this.table = new Table({
            style: { head: ['cyan'] },
            head: ['Property', 'Value'],
        });
        this.table.push(['Id', namespaceInfo.id.toHex()], ['Registration Type', namespaceInfo.isRoot() ? 'Root Namespace' : 'Sub Namespace'], ['Owner', namespaceInfo.ownerAddress.pretty()], ['Start Height', namespaceInfo.startHeight.toString()], ['End Height', namespaceInfo.endHeight.toString()]);
        if (namespaceInfo.isSubnamespace()) {
            this.table.push(['Parent Id', namespaceInfo.parentNamespaceId().toHex()]);
        }
        if (namespaceInfo.hasAlias()) {
            if (namespaceInfo.alias.address) {
                this.table.push(['Alias Type', 'Address'], ['Alias Address', namespaceInfo.alias.address.pretty()]);
            }
            else if (namespaceInfo.alias.mosaicId) {
                this.table.push(['Alias Type', 'MosaicId'], ['Alias MosaicId', namespaceInfo.alias.mosaicId.toHex()]);
            }
        }
    }
    toString() {
        let text = '';
        text += formatter_service_1.FormatterService.title('Namespace Information');
        text += '\n' + this.table.toString();
        return text;
    }
}
exports.NamespaceInfoTable = NamespaceInfoTable;
let default_1 = class default_1 extends profile_command_1.ProfileCommand {
    constructor() {
        super();
    }
    async execute(options) {
        const profile = this.getProfile(options);
        const namespaceId = options.namespaceName
            ? await new namespace_resolver_1.NamespaceNameResolver().resolve(options)
            : await new namespace_resolver_1.NamespaceIdResolver().resolve(options);
        this.spinner.start();
        const namespaceHttp = profile.repositoryFactory.createNamespaceRepository();
        namespaceHttp.getNamespace(namespaceId).subscribe((namespaceInfo) => {
            this.spinner.stop();
            console.log(new NamespaceInfoTable(namespaceInfo).toString());
        }, (err) => {
            this.spinner.stop();
            console.log(formatter_service_1.FormatterService.error(err));
        });
    }
};
__decorate([
    clime_1.metadata,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [CommandOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    clime_1.command({
        description: 'Fetch namespace info',
    }),
    __metadata("design:paramtypes", [])
], default_1);
exports.default = default_1;
