"use strict";
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandOptions = void 0;
const clime_1 = require("clime");
const symbol_sdk_1 = require("symbol-sdk");
const announce_transactions_command_1 = require("../../interfaces/announce.transactions.command");
const announce_transactions_options_1 = require("../../interfaces/announce.transactions.options");
const action_enum_1 = require("../../models/action.enum");
const action_resolver_1 = require("../../resolvers/action.resolver");
const maxFee_resolver_1 = require("../../resolvers/maxFee.resolver");
const password_resolver_1 = require("../../resolvers/password.resolver");
const restrictionAccount_resolver_1 = require("../../resolvers/restrictionAccount.resolver");
const transactionType_resolver_1 = require("../../resolvers/transactionType.resolver");
class CommandOptions extends announce_transactions_options_1.AnnounceTransactionsOptions {
}
__decorate([
    clime_1.option({
        flag: 'f',
        description: 'Restriction flag. (' + 'AllowOutgoingTransactionType,' + 'BlockOutgoingTransactionType)',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "flags", void 0);
__decorate([
    clime_1.option({
        flag: 'a',
        description: 'Modification action. (Add, Remove).',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "action", void 0);
__decorate([
    clime_1.option({
        flag: 'v',
        description: 'Transaction type formatted as hex.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "transactionType", void 0);
exports.CommandOptions = CommandOptions;
let default_1 = class default_1 extends announce_transactions_command_1.AnnounceTransactionsCommand {
    constructor() {
        super();
    }
    async execute(options) {
        const profile = this.getProfile(options);
        const password = await new password_resolver_1.PasswordResolver().resolve(options);
        const account = profile.decrypt(password);
        const action = await new action_resolver_1.ActionResolver().resolve(options);
        const flags = await new restrictionAccount_resolver_1.RestrictionAccountOperationFlagsResolver().resolve(options);
        const transactionType = await new transactionType_resolver_1.TransactionTypeResolver().resolve(options);
        const maxFee = await new maxFee_resolver_1.MaxFeeResolver().resolve(options);
        const multisigSigner = await this.getMultisigSigner(options);
        const transaction = symbol_sdk_1.AccountRestrictionTransaction.createOperationRestrictionModificationTransaction(symbol_sdk_1.Deadline.create(profile.epochAdjustment), flags, action === action_enum_1.ActionType.Add ? [transactionType] : [], action === action_enum_1.ActionType.Remove ? [transactionType] : [], profile.networkType, maxFee);
        const signatureOptions = {
            account,
            transactions: [transaction],
            maxFee,
            multisigSigner,
        };
        const signedTransactions = await this.signTransactions(signatureOptions, options);
        this.announceTransactions(options, signedTransactions);
    }
};
__decorate([
    clime_1.metadata,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [CommandOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    clime_1.command({
        description: 'Allow or block outgoing transactions by transaction type',
    }),
    __metadata("design:paramtypes", [])
], default_1);
exports.default = default_1;
