"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransactionStatusTable = exports.CommandOptions = void 0;
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
const Table = require("cli-table3");
const clime_1 = require("clime");
const profile_command_1 = require("../../interfaces/profile.command");
const profile_options_1 = require("../../interfaces/profile.options");
const hash_resolver_1 = require("../../resolvers/hash.resolver");
const formatter_service_1 = require("../../services/formatter.service");
class CommandOptions extends profile_options_1.ProfileOptions {
}
__decorate([
    clime_1.option({
        flag: 'h',
        description: 'Transaction hash.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "hash", void 0);
exports.CommandOptions = CommandOptions;
class TransactionStatusTable {
    constructor(status, profile) {
        this.status = status;
        this.table = new Table({
            style: { head: ['cyan'] },
            head: ['Property', 'Value'],
        });
        this.table.push(['Group', status.group], ['Hash', status.hash]);
        if (status.code) {
            this.table.push(['Status Code', status.code]);
        }
        if (status.deadline) {
            const localDateTime = status.deadline.toLocalDateTime(profile.epochAdjustment);
            this.table.push(['Deadline', `${localDateTime.toLocalDate()} ${localDateTime.toLocalTime()}`]);
        }
        if (status.height) {
            this.table.push(['Height', status.height.toString()]);
        }
    }
    toString() {
        let text = '';
        text += formatter_service_1.FormatterService.title('Transaction Status');
        text += '\n' + this.table.toString();
        return text;
    }
}
exports.TransactionStatusTable = TransactionStatusTable;
let default_1 = class default_1 extends profile_command_1.ProfileCommand {
    constructor() {
        super();
    }
    async execute(options) {
        const profile = this.getProfile(options);
        const hash = await new hash_resolver_1.HashResolver().resolve(options);
        this.spinner.start();
        const transactionStatusHttp = profile.repositoryFactory.createTransactionStatusRepository();
        transactionStatusHttp.getTransactionStatus(hash).subscribe((status) => {
            this.spinner.stop();
            console.log(new TransactionStatusTable(status, profile).toString());
        }, (err) => {
            this.spinner.stop();
            console.log(formatter_service_1.FormatterService.error(err));
        });
    }
};
__decorate([
    clime_1.metadata,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [CommandOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    clime_1.command({
        description: 'Fetch transaction status',
    }),
    __metadata("design:paramtypes", [])
], default_1);
exports.default = default_1;
