"use strict";
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandOptions = void 0;
const clime_1 = require("clime");
const symbol_sdk_1 = require("symbol-sdk");
const announce_transactions_command_1 = require("../../interfaces/announce.transactions.command");
const announce_transactions_options_1 = require("../../interfaces/announce.transactions.options");
const address_resolver_1 = require("../../resolvers/address.resolver");
const maxFee_resolver_1 = require("../../resolvers/maxFee.resolver");
const message_resolver_1 = require("../../resolvers/message.resolver");
const mosaic_resolver_1 = require("../../resolvers/mosaic.resolver");
const password_resolver_1 = require("../../resolvers/password.resolver");
const publicKey_resolver_1 = require("../../resolvers/publicKey.resolver");
class CommandOptions extends announce_transactions_options_1.AnnounceTransactionsOptions {
}
__decorate([
    clime_1.option({
        flag: 'r',
        description: 'Recipient address or @alias.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "recipientAddress", void 0);
__decorate([
    clime_1.option({
        flag: 'm',
        description: 'Transaction message.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "message", void 0);
__decorate([
    clime_1.option({
        flag: 'e',
        description: '(Optional) Send an encrypted message. ' + "If you set this value, you should set the value of 'recipientPublicKey' as well).",
        toggle: true,
    }),
    __metadata("design:type", Object)
], CommandOptions.prototype, "encrypted", void 0);
__decorate([
    clime_1.option({
        flag: 'c',
        description: 'Mosaic to transfer in the format (mosaicId(hex)|@aliasName)::absoluteAmount. Add multiple mosaics with commas.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "mosaics", void 0);
__decorate([
    clime_1.option({
        flag: 'u',
        description: '(Optional) Recipient public key in an encrypted message.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "recipientPublicKey", void 0);
exports.CommandOptions = CommandOptions;
let default_1 = class default_1 extends announce_transactions_command_1.AnnounceTransactionsCommand {
    constructor() {
        super();
    }
    async execute(options) {
        const profile = this.getProfile(options);
        const password = await new password_resolver_1.PasswordResolver().resolve(options);
        const account = profile.decrypt(password);
        const mosaics = await new mosaic_resolver_1.MosaicsResolver().resolve(options);
        let recipientAddress;
        let message = symbol_sdk_1.EmptyMessage;
        if (options.encrypted) {
            const recipientPublicAccount = await new publicKey_resolver_1.PublicKeyResolver().resolve(options, profile.networkType, 'Enter the recipient public key:', 'recipientPublicKey');
            recipientAddress = recipientPublicAccount.address;
            const rawMessage = await new message_resolver_1.MessageResolver().resolve(options);
            message = account.encryptMessage(rawMessage, recipientPublicAccount);
        }
        else {
            recipientAddress = await new address_resolver_1.UnresolvedAddressResolver().resolve(options, undefined, 'Enter the recipient address or @alias:', 'recipientAddress');
            const rawMessage = await new message_resolver_1.MessageResolver().resolve(options);
            if (rawMessage) {
                message = symbol_sdk_1.PlainMessage.create(rawMessage);
            }
        }
        const maxFee = await new maxFee_resolver_1.MaxFeeResolver().resolve(options);
        const multisigSigner = await this.getMultisigSigner(options);
        const transaction = symbol_sdk_1.TransferTransaction.create(symbol_sdk_1.Deadline.create(profile.epochAdjustment), recipientAddress, mosaics, message, profile.networkType, maxFee);
        const signatureOptions = {
            account,
            transactions: [transaction],
            maxFee,
            multisigSigner,
        };
        const signedTransactions = await this.signTransactions(signatureOptions, options);
        this.announceTransactions(options, signedTransactions);
    }
};
__decorate([
    clime_1.metadata,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [CommandOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    clime_1.command({
        description: 'Send transfer transaction',
    }),
    __metadata("design:paramtypes", [])
], default_1);
exports.default = default_1;
