"use strict";
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.BLSPublicKeyResolver = void 0;
const options_resolver_1 = require("../options-resolver");
const bls_validator_1 = require("../validators/bls.validator");
/**
 * BLS public key resolver
 */
class BLSPublicKeyResolver {
    /**
     * Resolves a BLS public key provided by the user.
     * @param {Options} options - Command options.
     * @param {string} altText - Alternative text.
     * @param {string} altKey - Alternative key.
     * @returns {Promise<PublicAccount>}
     */
    async resolve(options, altText, altKey) {
        const resolution = await options_resolver_1.OptionsResolver(options, altKey ? altKey : 'linkedPublicKey', () => undefined, altText ? altText : 'Enter the BLS public key: ', 'text', new bls_validator_1.BLSPublicKeyValidator());
        return resolution;
    }
}
exports.BLSPublicKeyResolver = BLSPublicKeyResolver;
