"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FinalizationPointResolver = void 0;
const symbol_sdk_1 = require("symbol-sdk");
const options_resolver_1 = require("../options-resolver");
const finalizationPoint_validator_1 = require("../validators/finalizationPoint.validator");
class FinalizationPointResolver {
    /**
     * Resolves a finalization point provided by user.
     * @param {Options} options - Command options.
     * @param {string} altText - Alternative text.
     * @param {string} altKey - Alternative key.
     * @returns {Promise<UInt64>}
     */
    async resolve(options, altText, altKey) {
        const resolution = await options_resolver_1.OptionsResolver(options, altKey ? altKey : 'point', () => undefined, altText ? altText : 'Enter a finalization point:', 'text', new finalizationPoint_validator_1.FinalizationPointValidator());
        return symbol_sdk_1.UInt64.fromNumericString(resolution);
    }
}
exports.FinalizationPointResolver = FinalizationPointResolver;
