"use strict";
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.OptionalPublicKeyResolver = exports.PublicKeyResolver = void 0;
const symbol_sdk_1 = require("symbol-sdk");
const options_resolver_1 = require("../options-resolver");
const publicKey_validator_1 = require("../validators/publicKey.validator");
/**
 * Public key resolver
 */
class PublicKeyResolver {
    /**
     * Resolves a public key provided by the user.
     * @param {Options} options - Command options.
     * @param {NetworkType} networkType - The network type.
     * @param {string} altText - Alternative text.
     * @param {string} altKey - Alternative key.
     * @returns {Promise<PublicAccount>}
     */
    async resolve(options, networkType, altText, altKey) {
        const resolution = await options_resolver_1.OptionsResolver(options, altKey ? altKey : 'publicKey', () => undefined, altText ? altText : 'Enter the account public key:', 'text', new publicKey_validator_1.PublicKeyValidator(networkType));
        return symbol_sdk_1.PublicAccount.createFromPublicKey(resolution, networkType);
    }
}
exports.PublicKeyResolver = PublicKeyResolver;
class OptionalPublicKeyResolver {
    /**
     * Resolves a public key provided by the user.
     * @param {Options} options - Command options.
     * @param {NetworkType} networkType - The network type.
     * @param {string} altText - Alternative text.
     * @param {string} altKey - Alternative key.
     * @returns {Promise<PublicAccount>}
     */
    async resolve(options, networkType, altText, altKey) {
        const resolution = await options_resolver_1.OptionsResolver(options, altKey ? altKey : 'publicKey', () => undefined, altText ? altText : 'Enter the account public key:', 'text', new publicKey_validator_1.OptionalPublicKeyValidator(networkType));
        if (!resolution) {
            return null;
        }
        return symbol_sdk_1.PublicAccount.createFromPublicKey(resolution, networkType);
    }
}
exports.OptionalPublicKeyResolver = OptionalPublicKeyResolver;
