"use strict";
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransactionTypeResolver = void 0;
const symbol_sdk_1 = require("symbol-sdk");
const options_resolver_1 = require("../options-resolver");
const transactionType_validator_1 = require("../validators/transactionType.validator");
/**
 * Transaction type resolver
 */
class TransactionTypeResolver {
    /**
     * Resolves a transaction type provided by the user.
     * @param {Options} options - Command options.
     * @param {string} altText - Alternative text.
     * @param {string} altKey - Alternative key.
     * @returns {Promise<number>}
     */
    async resolve(options, altText, altKey) {
        const choices = Object.keys(symbol_sdk_1.TransactionType)
            .filter((key) => Number.isNaN(parseFloat(key)) && key !== 'RESERVED')
            .map((string) => ({
            title: string,
            value: `${symbol_sdk_1.TransactionType[string]}`,
        }));
        const value = +(await options_resolver_1.OptionsChoiceResolver(options, altKey ? altKey : 'transactionType', altText ? altText : 'Chose a transaction type:', choices, 'select', new transactionType_validator_1.TransactionTypeValidator()));
        return value;
    }
}
exports.TransactionTypeResolver = TransactionTypeResolver;
