"use strict";
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.OptionalPublicKeyValidator = exports.PublicKeyValidator = void 0;
const symbol_sdk_1 = require("symbol-sdk");
/**
 * Public key validator
 */
class PublicKeyValidator {
    /**
     * @param networkType the configured network type.
     */
    constructor(networkType) {
        this.networkType = networkType;
    }
    /**
     * Validates a public key format.
     * @param {string} value - Public key.
     * @returns {true | string}
     */
    validate(value) {
        try {
            symbol_sdk_1.PublicAccount.createFromPublicKey(value, this.networkType);
        }
        catch (_a) {
            return 'Public key must be a 64 characters hexadecimal string';
        }
        return true;
    }
}
exports.PublicKeyValidator = PublicKeyValidator;
/**
 * Optional public key validator
 */
class OptionalPublicKeyValidator {
    /**
     * @param networkType the configured network type.
     */
    constructor(networkType) {
        this.networkType = networkType;
    }
    /**
     * Validates a public key format.
     * @param {string} value - Public key.
     * @returns {true | string}
     */
    validate(value) {
        try {
            if (value) {
                symbol_sdk_1.PublicAccount.createFromPublicKey(value, this.networkType);
            }
        }
        catch (_a) {
            return 'Public key must be a 64 characters hexadecimal string';
        }
        return true;
    }
}
exports.OptionalPublicKeyValidator = OptionalPublicKeyValidator;
