"use strict";
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransferView = void 0;
const mosaics_view_1 = require("../../../mosaics.view");
const recipients_view_1 = require("../../../recipients.view");
class TransferView {
    /**
     * Creates an instance of TransferView.
     * @param {TransferTransaction} tx
     */
    constructor(tx) {
        this.tx = tx;
    }
    /**
     * @static
     * @param {TransferTransaction} tx
     * @returns {CellRecord}
     */
    static get(tx) {
        return new TransferView(tx).render();
    }
    /**
     * @private
     * @returns {CellRecord}
     */
    render() {
        return {
            Recipient: this.getUnresolvedAddress(),
            Message: this.tx.message.payload || 'N/A',
            ...mosaics_view_1.MosaicsView.get(this.tx.mosaics),
        };
    }
    /**
     * @private
     * @returns {string}
     */
    getUnresolvedAddress() {
        if (!this.tx.recipientAddress) {
            return '';
        }
        return recipients_view_1.RecipientsView.get(this.tx.recipientAddress);
    }
}
exports.TransferView = TransferView;
